@@ -146,8 +146,8 @@ int vsi_dec_get_codec_format(struct vsi_v4l2_dev_info *hwinfo) {
   hwinfo->max_dec_resolution = 4096;
 #else
   DWLHwConfig hw_cfg[2] = {0};
-  unsigned long g1_dec_format = 0;
-  unsigned long g2_dec_format = 0;
+  uint64_t g1_dec_format = 0;
+  uint64_t g2_dec_format = 0;
 
   DWLReadAsicConfig(&hw_cfg[0], DWL_CLIENT_TYPE_H264_DEC);
   DWLReadAsicConfig(&hw_cfg[1], DWL_CLIENT_TYPE_HEVC_DEC);
@@ -212,13 +212,13 @@ void _dbg_write_input_data_(v4l2_dec_inst *h, uint32_t *vaddr, uint32_t size,
 
   switch (h->codec_fmt) {
     case V4L2_DAEMON_CODEC_DEC_HEVC:
-      sprintf(name, "recived_%lx_%d.hevc", h->instance_id, frame_id);
+      sprintf(name, "recived_%"PRIx64"_%d.hevc", h->instance_id, frame_id);
       break;
     case V4L2_DAEMON_CODEC_DEC_H264:
-      sprintf(name, "recived_%lx_%d.h264", h->instance_id, frame_id);
+      sprintf(name, "recived_%"PRIx64"_%d.h264", h->instance_id, frame_id);
       break;
     default:
-      sprintf(name, "recived_%lx_%d.bin", h->instance_id, frame_id);
+      sprintf(name, "recived_%"PRIx64"_%d.bin", h->instance_id, frame_id);
       break;
   }
 
@@ -400,7 +400,7 @@ static v4l2_inst_dec_event vsi_dec_handle_input_buffer(
 #endif
 
   HANTRO_LOG(HANTRO_LEVEL_DEBUG,
-             "Inst[%lx]: received one input buffer: id=%d, payloadSize=%d.\n",
+             "Inst[%"PRIx64"]: received one input buffer: id=%d, payloadSize=%d.\n",
              h->instance_id,
              msg->params.dec_params.io_buffer.inbufidx,
              msg->params.dec_params.io_buffer.bytesused);
@@ -424,7 +424,7 @@ static v4l2_inst_dec_event vsi_dec_handle_output_buffer(
 
   dpb_receive_buffer(h, index, buf);
 
-  HANTRO_LOG(HANTRO_LEVEL_DEBUG, "Inst[%lx]: received one output buffer: id=%d.\n",
+  HANTRO_LOG(HANTRO_LEVEL_DEBUG, "Inst[%"PRIx64"]: received one output buffer: id=%d.\n",
              h->instance_id,
              msg->params.dec_params.io_buffer.outbufidx);
   h->output_frame_cnt++;
@@ -482,7 +482,7 @@ void vsi_dec_flush_input_packet(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
   p = bufferlist_get_buffer(h->bufferlist_input);
 
   if (p == NULL) {
-    HANTRO_LOG(HANTRO_LEVEL_ERROR, "Inst[%lx]: SHOULD GET THE INPUT BUFFER.\n",
+    HANTRO_LOG(HANTRO_LEVEL_ERROR, "Inst[%"PRIx64"]: SHOULD GET THE INPUT BUFFER.\n",
                h->instance_id);
     ASSERT(0);
   }
@@ -513,7 +513,7 @@ re_get:
   p = bufferlist_get_buffer(h->bufferlist_input);
 
   if (p == NULL) {
-    HANTRO_LOG(HANTRO_LEVEL_INFO, "Inst[%lx]: should get one input buffer.\n",
+    HANTRO_LOG(HANTRO_LEVEL_INFO, "Inst[%"PRIx64"]: should get one input buffer.\n",
               h->instance_id);
     return -2;
   }
@@ -522,7 +522,7 @@ re_get:
   in_buf = &p->dec_cmd.io_buffer;
 
   if (in_buf->bytesused == 0) {
-    HANTRO_LOG(HANTRO_LEVEL_ERROR, "Inst[%lx]: input payload size is zero!\n",
+    HANTRO_LOG(HANTRO_LEVEL_ERROR, "Inst[%"PRIx64"]: input payload size is zero!\n",
               h->instance_id);
     vsi_dec_flush_input_packet(h, NULL);
     goto re_get;
@@ -535,7 +535,7 @@ re_get:
   uint32_t *virtual_address =
       mmap_phy_addr_daemon(mmap_fd, in_buf->busInBuf, aligned_map_size);
   if (virtual_address == NULL) {
-    HANTRO_LOG(HANTRO_LEVEL_ERROR, "Inst[%lx]: MMAP Input Buffer FAILED\n",
+    HANTRO_LOG(HANTRO_LEVEL_ERROR, "Inst[%"PRIx64"]: MMAP Input Buffer FAILED\n",
                h->instance_id);
     ASSERT(0);
     return -1;
@@ -587,11 +587,11 @@ re_get:
     resyncTSManager(h->tsm, in_buf->timestamp, MODE_AI);
     h->need_resync_tsm = 0;
   }
-  HANTRO_LOG(HANTRO_LEVEL_INFO, "Inst[%lx]: input time stamp: %ld len: %d\n",
-             h->instance_id,
-             in_buf->timestamp, in_buf->bytesused);
   TSManagerReceive2(h->tsm, in_buf->timestamp, in_buf->bytesused);
 #endif
+  HANTRO_LOG(HANTRO_LEVEL_INFO, "Inst[%"PRIx64"]: input time stamp: %ld len: %d\n",
+             h->instance_id,
+             in_buf->timestamp, in_buf->bytesused);
   h->dec_in_pic_id = p->frame_display_id;
   h->dec_inpkt_pic_decoded_cnt = h->dec_pic_id;
   h->dec_in_new_packet = 1;
@@ -626,7 +626,7 @@ static void vsi_dec_handle_inpkt_cnt(v4l2_dec_inst *h) {
 
     p = bufferlist_get_buffer(h->bufferlist_input);
     if (p == NULL) {
-        HANTRO_LOG(HANTRO_LEVEL_ERROR, "Inst[%lx]: SHOULD GET INPUT BUFFER.\n",
+        HANTRO_LOG(HANTRO_LEVEL_ERROR, "Inst[%"PRIx64"]: SHOULD GET INPUT BUFFER.\n",
                     h->instance_id);
         ASSERT(0);
     } else {
@@ -665,7 +665,7 @@ void vsi_dec_update_input_data(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
 void vsi_dec_flush_input(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
   uint32_t avails = bufferlist_get_size(h->bufferlist_input);
 
-  HANTRO_LOG(HANTRO_LEVEL_INFO, "Inst[%lx]: flush input avails: %d\n",
+  HANTRO_LOG(HANTRO_LEVEL_INFO, "Inst[%"PRIx64"]: flush input avails: %d\n",
              h->instance_id, avails);
   for (int i = 0; i < avails; i++) {
     vsi_dec_flush_input_packet(h, v4l2_msg);
@@ -695,7 +695,7 @@ void vsi_dec_flush_output(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
     }
   }
   dpb_destroy(h);
-  HANTRO_LOG(HANTRO_LEVEL_INFO, "Inst[%lx]: currently existed dpb nums %d\n",
+  HANTRO_LOG(HANTRO_LEVEL_INFO, "Inst[%"PRIx64"]: currently existed dpb nums %d\n",
              h->instance_id,
              h->existed_dpb_nums);
 }
@@ -715,11 +715,11 @@ int vsi_dec_dequeue_pic(v4l2_dec_inst *h) {
   ASSERT(dec);
   ret = dec->get_pic(h, &tmp_pic, h->dec_capture_eos);
 
-  HANTRO_LOG(HANTRO_LEVEL_INFO, "Inst[%lx]: get pic ret %d\n",
+  HANTRO_LOG(HANTRO_LEVEL_INFO, "Inst[%"PRIx64"]: get pic ret %d\n",
              h->instance_id, ret);
   if (ret && !h->dec_capture_eos) {
     HANTRO_LOG(HANTRO_LEVEL_INFO,
-               "Inst[%lx]: didn't have available picture for dequeue.\n",
+               "Inst[%"PRIx64"]: didn't have available picture for dequeue.\n",
                h->instance_id);
     return DEQUEUE_ERR_PIC_NOT_AVAIL;
   }
@@ -730,7 +730,7 @@ int vsi_dec_dequeue_pic(v4l2_dec_inst *h) {
     if (h->dec_drain_tid == 0) {
       pthread_join(h->dec_drain_thread, NULL);
       h->dec_drain_tid = -1;
-      HANTRO_LOG(HANTRO_LEVEL_INFO, "Inst[%lx]: joined drain thread.\n",
+      HANTRO_LOG(HANTRO_LEVEL_INFO, "Inst[%"PRIx64"]: joined drain thread.\n",
                  h->instance_id);
     }
   } else {
@@ -779,7 +779,7 @@ int vsi_dec_dequeue_pic(v4l2_dec_inst *h) {
         vsi_dec_get_timestamp(h, tmp_pic.pic_id);
 #endif
     HANTRO_LOG(HANTRO_LEVEL_INFO,
-               "Inst[%lx]: output time stamp: %ld buffer[id: %d}: %d\n",
+               "Inst[%"PRIx64"]: output time stamp: %ld buffer[id: %d}: %d\n",
                h->instance_id,
                msg.params.dec_params.io_buffer.timestamp,
                id, h->dpb_buffers[id].buff_idx);
@@ -788,7 +788,7 @@ int vsi_dec_dequeue_pic(v4l2_dec_inst *h) {
     h->dec_last_pic_sent = 1;
     h->dec_capture_eos = 0;
     msg.params.dec_params.io_buffer.timestamp = 0;
-    HANTRO_LOG(HANTRO_LEVEL_INFO, "Inst[%lx]: last pic is sent out.\n",
+    HANTRO_LOG(HANTRO_LEVEL_INFO, "Inst[%"PRIx64"]: last pic is sent out.\n",
               h->instance_id);
   }
   send_notif_to_v4l2(pipe_fd, &msg, sizeof(struct vsi_v4l2_msg_hdr) +
@@ -846,12 +846,12 @@ int vsi_dec_drop_pic(v4l2_dec_inst *h) {
   ret = dec->get_pic(h, &tmp_pic, h->dec_capture_eos);
   if (ret) {
     HANTRO_LOG(HANTRO_LEVEL_INFO,
-               "Inst[%lx]: didn't have available picture for dequeue.\n",
+               "Inst[%"PRIx64"]: didn't have available picture for dequeue.\n",
                h->instance_id);
     return -1;
   }
 
-  HANTRO_LOG(HANTRO_LEVEL_INFO, "Inst[%lx]: release picture: bus_addr=0x%llx\n",
+  HANTRO_LOG(HANTRO_LEVEL_INFO, "Inst[%"PRIx64"]: release picture: bus_addr=0x%"PRIx64"\n",
              h->instance_id,
              tmp_pic.output_picture_bus_address);
   dec->release_pic(h, tmp_pic.priv_pic_data);
@@ -865,7 +865,7 @@ void *vsi_dec_send_eos(void *arg) {
       (vsi_v4l2m2m2_deccodec *)(h->vsi_v4l2m2m_decoder);
   int ret = 0;
   ret = dec->drain(h);
-  HANTRO_LOG(HANTRO_LEVEL_INFO, "Inst[%lx]: END, ret %d\n", h->instance_id, ret);
+  HANTRO_LOG(HANTRO_LEVEL_INFO, "Inst[%"PRIx64"]: END, ret %d\n", h->instance_id, ret);
   return NULL;
 }
 
@@ -907,7 +907,7 @@ v4l2_inst_dec_event vsi_dec_destroy(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
   if (h->dec_drain_tid == 0) {
     pthread_join(h->dec_drain_thread, NULL);
     h->dec_drain_tid = -1;
-    HANTRO_LOG(HANTRO_LEVEL_INFO, "Inst[%lx]: joined drain thread.\n",
+    HANTRO_LOG(HANTRO_LEVEL_INFO, "Inst[%"PRIx64"]: joined drain thread.\n",
               h->instance_id);
   }
 
@@ -1076,7 +1076,7 @@ static void vsi_dec_set_crop(v4l2_dec_inst *h) {
   h->pic_info.height = h->dec_info.frame_height;
   h->pic_info.pic_wstride = h->dec_info.pic_wstride;
 
-  HANTRO_LOG(HANTRO_LEVEL_INFO, "Inst[%lx]: crop info is updated.\n",
+  HANTRO_LOG(HANTRO_LEVEL_INFO, "Inst[%"PRIx64"]: crop info is updated.\n",
              h->instance_id);
 }
 
@@ -1100,7 +1100,7 @@ static int vsi_dec_check_crop(v4l2_dec_inst *h, vsi_v4l2_dec_picture *new_pic) {
   h->pic_info.height = new_pic->pic_height;
   h->pic_info.pic_wstride = new_pic->pic_stride;
 
-  HANTRO_LOG(HANTRO_LEVEL_INFO, "Inst[%lx]: crop info is different @ frame %d.\n",
+  HANTRO_LOG(HANTRO_LEVEL_INFO, "Inst[%"PRIx64"]: crop info is different @ frame %d.\n",
              h->instance_id, h->dec_pic_id);
   return 1;
 }
@@ -1129,7 +1129,7 @@ static v4l2_inst_dec_event vsi_dec_handle_cropchange(v4l2_dec_inst *h) {
                      sizeof(struct vsi_v4l2_msg_hdr) +
                          sizeof(struct v4l2_daemon_dec_pictureinfo_params));
 
-  HANTRO_LOG(HANTRO_LEVEL_INFO, "Inst[%lx]: crop change event is sent.\n",
+  HANTRO_LOG(HANTRO_LEVEL_INFO, "Inst[%"PRIx64"]: crop change event is sent.\n",
              h->instance_id);
   return DEC_EMPTY_EVENT;
 }
@@ -1175,6 +1175,7 @@ v4l2_inst_dec_event vsi_dec_streaming_output(v4l2_dec_inst *h,
 
   switch (dec_event) {
     case DEC_SOURCE_CHANGE_EVENT:
+      h->seq_hdr_parsed = 1;
       vsi_dec_handle_reschange(h);
       break;
 
@@ -1191,7 +1192,7 @@ v4l2_inst_dec_event vsi_dec_streaming_output(v4l2_dec_inst *h,
       else
         vsi_dec_send_eos(h);
 
-      HANTRO_LOG(HANTRO_LEVEL_INFO, "Inst[%lx]: DecEndOfStream\n",
+      HANTRO_LOG(HANTRO_LEVEL_INFO, "Inst[%"PRIx64"]: DecEndOfStream\n",
                  h->instance_id);
       break;
 
@@ -1266,6 +1267,29 @@ v4l2_inst_dec_event vsi_dec_streaming_capture(v4l2_dec_inst *h,
   return dec_event;
 }
 
+void vsi_dec_fsm_event_check(v4l2_dec_inst *h, v4l2_decoder_fsm_element *element)
+{
+  if (element->flags & DAEMON_DEC_STATE_TRANS_UNEXPECTED)
+    HANTRO_LOG(HANTRO_LEVEL_WARNING,
+               "there may be some risk for Inst[%"PRIx64"]: event [%s], state [%s] -> [%s]\n",
+               h->instance_id,
+               dec_event_name[element->dec_event],
+               dec_state_name[element->cur_state],
+               dec_state_name[element->next_state]);
+
+  /*further check*/
+  if (element->next_state == DAEMON_DEC_STATE_DECODE && element->cur_state != element->next_state) {
+      if ((h->dec_output_state != DAEMON_QUEUE_STATE_ON && h->dec_output_state != DAEMON_QUEUE_STATE_PEND_OFF) ||
+          h->dec_capture_state != DAEMON_QUEUE_STATE_ON)
+        HANTRO_LOG(HANTRO_LEVEL_WARNING, "Inst[%"PRIx64"] isn't ready for decode, event [%s], state [%s] -> [%s], queue state[%d, %d]\n",
+                   h->instance_id,
+                   dec_event_name[element->dec_event],
+                   dec_state_name[element->cur_state],
+                   dec_state_name[element->next_state],
+                   h->dec_output_state, h->dec_capture_state);
+  }
+}
+
 /**
  * @brief vsi_dec_fsm_event_handle(), decoder message processor.
  * @param v4l2_dec_inst* h: decoder instance.
@@ -1277,7 +1301,7 @@ int32_t vsi_dec_fsm_event_handle(void *codec, struct vsi_v4l2_msg *v4l2_msg) {
   v4l2_inst_dec_event dec_event = DEC_EMPTY_EVENT;
 
   dec_event = vsi_dec_trans_v4l2cmdid_to_eventid(h, v4l2_msg);
-  HANTRO_LOG(HANTRO_LEVEL_DEBUG, "Inst[%lx]: receive event [%s]\n",
+  HANTRO_LOG(HANTRO_LEVEL_DEBUG, "Inst[%"PRIx64"]: receive event [%s]\n",
              h->instance_id,
              dec_event_name[dec_event]);
   if (DEC_CACHE_IO_BUFFER_EVENT == dec_event) {
@@ -1289,15 +1313,17 @@ int32_t vsi_dec_fsm_event_handle(void *codec, struct vsi_v4l2_msg *v4l2_msg) {
 
     if (INVALIDE_DEC_TABLE_INDEX != status_index) {
       HANTRO_LOG(
-          HANTRO_LEVEL_DEBUG, "Inst[%lx]: event [%s], state [%s] -> [%s]\n",
+          HANTRO_LEVEL_DEBUG, "Inst[%"PRIx64"]: event [%s], state [%s] -> [%s]\n",
           h->instance_id,
           dec_event_name[dec_event], dec_state_name[h->dec_cur_state],
           dec_state_name[vsi_v4l2dec_fsm_trans_table[status_index].next_state]);
 
+
       if (vsi_v4l2dec_fsm_trans_table[status_index].eventActFun) {
         int ret =
             vsi_v4l2dec_fsm_trans_table[status_index].eventActFun(h, v4l2_msg);
         if (0 == ret) {
+          vsi_dec_fsm_event_check(h, &vsi_v4l2dec_fsm_trans_table[status_index]);
           h->dec_cur_state =
               vsi_v4l2dec_fsm_trans_table[status_index].next_state;
         }
@@ -1321,7 +1347,7 @@ int32_t vsi_dec_fsm_event_handle(void *codec, struct vsi_v4l2_msg *v4l2_msg) {
 
   vsi_dec_msg_done(h, v4l2_msg);
   HANTRO_LOG(HANTRO_LEVEL_DEBUG,
-             "Inst[%lx]: finish one external event, curr state [%s] \n",
+             "Inst[%"PRIx64"]: finish one external event, curr state [%s] \n",
              h->instance_id,
              dec_state_name[h->dec_cur_state]);
   return (h->dec_cur_state == DAEMON_DEC_STATE_DESTROYED);
@@ -1428,7 +1454,7 @@ int vsi_dec_set_format(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
 #ifndef DEC_INPUT_NO_COPY
   if (h->secure_mode_on) {
     HANTRO_LOG(HANTRO_LEVEL_ERROR,
-               "Inst[%lx]: Not support secure playback in INPUT_COPY mode!\n",
+               "Inst[%"PRIx64"]: Not support secure playback in INPUT_COPY mode!\n",
                h->instance_id);
   }
 #endif
@@ -1437,7 +1463,7 @@ int vsi_dec_set_format(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
   vsi_dec_init(h, v4l2_msg);
   if (h->decoder_inst == NULL) {
     HANTRO_LOG(HANTRO_LEVEL_ERROR,
-               "Inst[%lx]: Failed to create decoder instance for format %d\n",
+               "Inst[%"PRIx64"]: Failed to create decoder instance for format %d\n",
                h->instance_id,
                h->codec_fmt);
     ASSERT(0);
@@ -1693,7 +1719,7 @@ int vsi_dec_seek3(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
     h->dec_output_state2 = 0;
   }
 
-  if (h->existed_dpb_nums)
+  if (h->existed_dpb_nums || !h->seq_hdr_parsed)
     h->dec_output_state = DAEMON_QUEUE_STATE_ON;
   else
     h->dec_output_state = DAEMON_QUEUE_STATE_PAUSE;
@@ -1785,7 +1811,7 @@ int vsi_dec_reschange2(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
     ;
    vsi_dec_flush_output(h, v4l2_msg);
   h->dec_capture_state = DAEMON_QUEUE_STATE_OFF;
-  HANTRO_LOG(HANTRO_LEVEL_INFO, "Inst[%lx]: Reveive CAPTURE_OFF @ source_change\n",
+  HANTRO_LOG(HANTRO_LEVEL_INFO, "Inst[%"PRIx64"]: Reveive CAPTURE_OFF @ source_change\n",
              h->instance_id);
   return 0;
 }
@@ -1944,13 +1970,13 @@ v4l2_decoder_fsm_element vsi_v4l2dec_fsm_trans_table[] = {
 
     /*CAPTURE-SETUP*/
     {DEC_SOURCE_CHANGE_EVENT,       DAEMON_DEC_STATE_CAPTURE_SETUP,     vsi_dec_capture_setup1,     DAEMON_DEC_STATE_CAPTURE_SETUP},
-    {DEC_RECEIVE_OUTPUTOFF_EVENT,   DAEMON_DEC_STATE_CAPTURE_SETUP,     vsi_dec_seek0,              DAEMON_DEC_STATE_SEEK},
+    {DEC_RECEIVE_OUTPUTOFF_EVENT,   DAEMON_DEC_STATE_CAPTURE_SETUP,     vsi_dec_seek0,              DAEMON_DEC_STATE_SEEK, DAEMON_DEC_STATE_TRANS_UNEXPECTED},
     {DEC_RECEIVE_CAPTUREOFF_EVENT,  DAEMON_DEC_STATE_CAPTURE_SETUP,     vsi_dec_capture_setup4,     DAEMON_DEC_STATE_CAPTURE_SETUP},
     {DEC_RECEIVE_CMDSTART_EVENT,    DAEMON_DEC_STATE_CAPTURE_SETUP,     vsi_dec_capture_setup3,     DAEMON_DEC_STATE_DECODE},
     {DEC_RECEIVE_CMDSTOP_EVENT,     DAEMON_DEC_STATE_CAPTURE_SETUP,     vsi_dec_drain2,             DAEMON_DEC_STATE_CAPTURE_SETUP},
     {DEC_RECEIVE_CAPTUREON_EVENT,   DAEMON_DEC_STATE_CAPTURE_SETUP,     vsi_dec_capture_setup3,     DAEMON_DEC_STATE_DECODE},
     {DEC_GOT_EOS_MARK_EVENT,        DAEMON_DEC_STATE_CAPTURE_SETUP,     vsi_dec_drain1,             DAEMON_DEC_STATE_DRAIN},
-    {DEC_LAST_PIC_EVENT,            DAEMON_DEC_STATE_CAPTURE_SETUP,     vsi_dec_stop0,              DAEMON_DEC_STATE_STOPPED},
+    {DEC_LAST_PIC_EVENT,            DAEMON_DEC_STATE_CAPTURE_SETUP,     vsi_dec_stop0,              DAEMON_DEC_STATE_STOPPED, DAEMON_DEC_STATE_TRANS_UNEXPECTED},
     {DEC_RECEIVE_DESTROY_EVENT,     DAEMON_DEC_STATE_CAPTURE_SETUP,     vsi_dec_stop3,              DAEMON_DEC_STATE_DESTROYED},
     {DEC_FATAL_ERROR_EVENT,         DAEMON_DEC_STATE_CAPTURE_SETUP,     vsi_dec_fatal_error1,       DAEMON_DEC_STATE_STOPPED},
 
@@ -1959,8 +1985,8 @@ v4l2_decoder_fsm_element vsi_v4l2dec_fsm_trans_table[] = {
     {DEC_PENDING_FLUSH_EVENT,       DAEMON_DEC_STATE_DECODE,            vsi_dec_pause0,             DAEMON_DEC_STATE_DECODE},
     {DEC_SOURCE_CHANGE_EVENT,       DAEMON_DEC_STATE_DECODE,            vsi_dec_reschange0,         DAEMON_DEC_STATE_SOURCE_CHANGE},
     {DEC_RECEIVE_OUTPUTOFF_EVENT,   DAEMON_DEC_STATE_DECODE,            vsi_dec_seek0,              DAEMON_DEC_STATE_SEEK},
-    {DEC_RECEIVE_CAPTUREOFF_EVENT,  DAEMON_DEC_STATE_DECODE,            vsi_dec_capture_setup2,     DAEMON_DEC_STATE_CAPTURE_SETUP},
-    {DEC_RECEIVE_CAPTUREON_EVENT,   DAEMON_DEC_STATE_DECODE,            vsi_dec_capture_setup3,     DAEMON_DEC_STATE_DECODE},
+    {DEC_RECEIVE_CAPTUREOFF_EVENT,  DAEMON_DEC_STATE_DECODE,            vsi_dec_capture_setup2,     DAEMON_DEC_STATE_CAPTURE_SETUP, DAEMON_DEC_STATE_TRANS_UNEXPECTED},
+    {DEC_RECEIVE_CAPTUREON_EVENT,   DAEMON_DEC_STATE_DECODE,            vsi_dec_capture_setup3,     DAEMON_DEC_STATE_DECODE, DAEMON_DEC_STATE_TRANS_UNEXPECTED},
     {DEC_RECEIVE_CMDSTOP_EVENT,     DAEMON_DEC_STATE_DECODE,            vsi_dec_drain0,             DAEMON_DEC_STATE_DRAIN},
     {DEC_GOT_EOS_MARK_EVENT,        DAEMON_DEC_STATE_DECODE,            vsi_dec_drain1,             DAEMON_DEC_STATE_DRAIN},
     {DEC_FATAL_ERROR_EVENT,         DAEMON_DEC_STATE_DECODE,            vsi_dec_fatal_error2,       DAEMON_DEC_STATE_STOPPED},
@@ -1978,7 +2004,7 @@ v4l2_decoder_fsm_element vsi_v4l2dec_fsm_trans_table[] = {
     /*SOURCE(RESOLUTION) CHANGE*/
     {DEC_LAST_PIC_EVENT,            DAEMON_DEC_STATE_SOURCE_CHANGE,     vsi_dec_reschange1,         DAEMON_DEC_STATE_CAPTURE_SETUP},
     {DEC_RECEIVE_OUTPUTOFF_EVENT,   DAEMON_DEC_STATE_SOURCE_CHANGE,     vsi_dec_seek0,              DAEMON_DEC_STATE_SEEK},
-    {DEC_RECEIVE_CAPTUREON_EVENT,   DAEMON_DEC_STATE_SOURCE_CHANGE,     vsi_dec_trans_state,        DAEMON_DEC_STATE_CAPTURE_SETUP},
+    {DEC_RECEIVE_CAPTUREON_EVENT,   DAEMON_DEC_STATE_SOURCE_CHANGE,     vsi_dec_capture_setup3,     DAEMON_DEC_STATE_DECODE},
     {DEC_RECEIVE_CAPTUREOFF_EVENT,  DAEMON_DEC_STATE_SOURCE_CHANGE,     vsi_dec_reschange2,         DAEMON_DEC_STATE_CAPTURE_SETUP},
     {DEC_RECEIVE_DESTROY_EVENT,     DAEMON_DEC_STATE_SOURCE_CHANGE,     vsi_dec_stop3,              DAEMON_DEC_STATE_DESTROYED},
 
@@ -1998,10 +2024,10 @@ v4l2_decoder_fsm_element vsi_v4l2dec_fsm_trans_table[] = {
     {DEC_FATAL_ERROR_EVENT,         DAEMON_DEC_STATE_DRAIN,             vsi_dec_fatal_error1,       DAEMON_DEC_STATE_STOPPED},
 
     /*STOPPPED*/
-    {DEC_RECEIVE_OUTPUTOFF_EVENT,   DAEMON_DEC_STATE_STOPPED,           vsi_dec_seek0,              DAEMON_DEC_STATE_SEEK}, 
-    {DEC_RECEIVE_OUTPUTON_EVENT,    DAEMON_DEC_STATE_STOPPED,           vsi_dec_stop1,              DAEMON_DEC_STATE_DECODE},
+    {DEC_RECEIVE_OUTPUTOFF_EVENT,   DAEMON_DEC_STATE_STOPPED,           vsi_dec_seek0,              DAEMON_DEC_STATE_SEEK},
+    {DEC_RECEIVE_OUTPUTON_EVENT,    DAEMON_DEC_STATE_STOPPED,           vsi_dec_stop1,              DAEMON_DEC_STATE_DECODE, DAEMON_DEC_STATE_TRANS_UNEXPECTED},
     {DEC_RECEIVE_CAPTUREOFF_EVENT,  DAEMON_DEC_STATE_STOPPED,           vsi_dec_stop5,              DAEMON_DEC_STATE_STOPPED},
-    {DEC_RECEIVE_CAPTUREON_EVENT,   DAEMON_DEC_STATE_STOPPED,           vsi_dec_seek2,              DAEMON_DEC_STATE_DECODE},
+    {DEC_RECEIVE_CAPTUREON_EVENT,   DAEMON_DEC_STATE_STOPPED,           vsi_dec_seek2,              DAEMON_DEC_STATE_DECODE, DAEMON_DEC_STATE_TRANS_UNEXPECTED},
     {DEC_RECEIVE_DESTROY_EVENT,     DAEMON_DEC_STATE_STOPPED,           vsi_dec_stop2,              DAEMON_DEC_STATE_DESTROYED},
 
 };
