@@ -37,7 +37,7 @@
  * Macros definitions
  *
  ***************************************************************************/
-#define NXP_TIMESTAMP_MANAGER
+//#define NXP_TIMESTAMP_MANAGER
 
 #define MAX_DEC_BUFFERS 32
 #define TIMESTAMP_SLOT_NUM 256
@@ -118,12 +118,11 @@ typedef enum {
   // indrirectly motivate
   DEC_BUFFER_EVENT,
   DEC_LAST_PIC_EVENT,
-  DEC_CACHE_IO_BUFFER_EVENT,  // 9
+  DEC_CACHE_IO_BUFFER_EVENT,  // 10
   DEC_FAKE_EVENT,
   // internal motivate
   DEC_SOURCE_CHANGE_EVENT,
   DEC_PIC_DECODED_EVENT,
-  DEC_DECODING_FAILED_EVENT,
   DEC_GOT_EOS_MARK_EVENT,
   DEC_NO_DECODING_BUFFER_EVENT,    // buffer is not consumed
   DEC_WAIT_DECODING_BUFFER_EVENT,  // no decoding buffer set to decoder yet
@@ -150,11 +149,17 @@ enum v4l2_daemon_dpb_status {
  *
  ***************************************************************************/
 typedef struct _v4l2_dec_inst v4l2_dec_inst;
+
+enum {
+    DAEMON_DEC_STATE_TRANS_UNEXPECTED = (1 << 8),
+};
+
 typedef struct {
   v4l2_inst_dec_event dec_event;
   v4l2_inst_dec_state cur_state;
   int (*eventActFun)(v4l2_dec_inst *, vsi_v4l2_msg *);
   v4l2_inst_dec_state next_state;
+  uint32_t flags;
 } v4l2_decoder_fsm_element;
 
 struct v4l2_decoder_dbp {
@@ -166,7 +171,7 @@ struct v4l2_decoder_dbp {
 
 struct _v4l2_dec_inst {
   v4l2_daemon_codec_fmt codec_fmt;
-  unsigned long instance_id;
+  uint64_t instance_id;
 
   /*handlers*/
   v4l2_daemon_inst *handler;
@@ -243,12 +248,14 @@ struct _v4l2_dec_inst {
   /*status flags*/
   int32_t dec_fatal_error;
   uint32_t dec_aborted;
+  uint32_t seq_hdr_parsed;
 
   /*privates related to different formats*/
   void *priv_data;
   void *priv_pic_data;
   uint32_t dec_inpkt_ignore_picconsumed_event;
   uint32_t discard_dbp_count;
+  uint32_t dec_inpkt_flag;
 
   /*obsoleted*/
   void *dec_dll_handle;
