@@ -124,10 +124,10 @@ static void signalhandler(int signo) {
   if (inst_p == NULL)
     inst_p = find_zombieinst(tid);
   if (inst_p != NULL) {
-    HANTRO_LOG(HANTRO_LEVEL_ERROR, "%s: catch exception for ctx %lx !!!!!\r\n",
+    HANTRO_LOG(HANTRO_LEVEL_ERROR, "%s: catch exception for ctx %"PRIx64" !!!!!\r\n",
                __FUNCTION__, inst_p->instance_id);
     if (inst_p->flag & (1 << INST_CATCH_EXCEPTION)) {
-      HANTRO_LOG(HANTRO_LEVEL_ERROR, "%s: repeatedly catch exception for ctx %lx !!!!!\r",
+      HANTRO_LOG(HANTRO_LEVEL_ERROR, "%s: repeatedly catch exception for ctx %"PRIx64" !!!!!\r",
         __FUNCTION__, inst_p->instance_id);
       inst_p->flag |= (1 << INST_FATAL_ERROR);
     } else {
@@ -227,7 +227,7 @@ static void check_zombieinst(void)
                 pthread_kill(pz->pinst->tid, SIGUSR1);
         }
         if (done) {
-            HANTRO_LOG(HANTRO_LEVEL_WARNING, "release zombie inst %lx with %d\n", pz->pinst->instance_id, ret);
+            HANTRO_LOG(HANTRO_LEVEL_WARNING, "release zombie inst %"PRIx64" with %d\n", pz->pinst->instance_id, ret);
             if (done) {
                 inst_destroy(pz->pinst);
                 free(pz->pinst);
@@ -266,7 +266,7 @@ static void removeall_zombieinst(void)
         while (pz) {
             pn = pz->next;
             if (pz->pinst->flag & (1 << INST_DEAD)){
-                HANTRO_LOG(HANTRO_LEVEL_WARNING, "release zombie inst %lx in tail\n", pz->pinst->instance_id);
+                HANTRO_LOG(HANTRO_LEVEL_WARNING, "release zombie inst %"PRIx64" in tail\n", pz->pinst->instance_id);
                 inst_destroy(pz->pinst);
                 free(pz->pinst);
                 free(pz);
@@ -447,7 +447,7 @@ int32_t main(int32_t argc, char **argv) {
             semtime.tv_nsec += 50000000;	//20ms should be enough for normal exit
             ret = sem_timedwait(&cur_inst_p->sem_done, &semtime);
             if (ret != 0) {
-              HANTRO_LOG(HANTRO_LEVEL_WARNING, "wait %lx exit timeout\n", cur_inst_p->instance_id);
+              HANTRO_LOG(HANTRO_LEVEL_WARNING, "wait %"PRIx64" exit timeout\n", cur_inst_p->instance_id);
 
               hash_table_remove(&ht, vsi_v4l2_cmd_p.msg.inst_id, 0);
               if (add_zombieinst(cur_inst_p, &semtime)) {
@@ -484,13 +484,13 @@ void *worker_threads(void *arg) {
   int ret = 0;
   v4l2_daemon_inst *h = (v4l2_daemon_inst *)arg;
   vsi_v4l2_cmd *v4l2_cmd = NULL;
-  unsigned long inst_id = NO_RESPONSE_SEQID;
+  uint64_t inst_id = NO_RESPONSE_SEQID;
   int32_t proc_result = 0;
 
   ret = sigsetjmp(h->sigbuf, 1);
   if (ret != 0) {
     // send error msg to driver
-    HANTRO_LOG(HANTRO_LEVEL_ERROR, " %lx catch exception \n", inst_id);
+    HANTRO_LOG(HANTRO_LEVEL_ERROR, "%"PRIx64"  catch exception \n", inst_id);
     if (h->flag & (1 << INST_ZOMBIE))
         h->flag |= (1 << INST_DEAD);
     if (h->flag & (1 << INST_FORCEEXIT))
@@ -508,12 +508,12 @@ void *worker_threads(void *arg) {
       inst_id = v4l2_cmd->msg.inst_id;
     } else if (inst_id != v4l2_cmd->msg.inst_id) {
       HANTRO_LOG(HANTRO_LEVEL_ERROR,
-                 "cmd and thread seqid mismatch 0x%lx-0x%lx.\n",
+                 "cmd and thread seqid mismatch 0x%"PRIx64"-0x%"PRIx64".\n",
                  v4l2_cmd->msg.inst_id, inst_id);
     }
     h->pop_cnt++;
     HANTRO_LOG(HANTRO_LEVEL_LOG,
-               "worker_threads inst[%ld]: codec_fmt %d, cmd id %d\n",
+               "worker_threads inst[%"PRIx64"]: codec_fmt %d, cmd id %d\n",
                h->instance_id, v4l2_cmd->msg.codec_fmt, v4l2_cmd->msg.cmd_id);
 
     /* process msg */
@@ -525,7 +525,7 @@ void *worker_threads(void *arg) {
     object_heap_free(&h->cmds, (object_base_p)v4l2_cmd);
 
     if (proc_result) {
-      HANTRO_LOG(HANTRO_LEVEL_DEBUG, "Instance [%ld] codec finished all jobs\n",
+      HANTRO_LOG(HANTRO_LEVEL_DEBUG, "Instance [%"PRIx64"] codec finished all jobs\n",
                  h->instance_id);
       break;
     }
@@ -534,7 +534,7 @@ void *worker_threads(void *arg) {
 
 label_worker_done:
   sem_post(&h->sem_done);
-  HANTRO_LOG(HANTRO_LEVEL_DEBUG, "worker_threads finish, instance id %lx\n",
+  HANTRO_LOG(HANTRO_LEVEL_DEBUG, "worker_threads finish, instance id %"PRIx64"\n",
              h->instance_id);
   return NULL;
 }
@@ -667,7 +667,7 @@ int inst_destroy(v4l2_daemon_inst *h) {
     if (!(h->flag & (1 << INST_CATCH_EXCEPTION)))
       h->func.destroy(h->codec);
     else
-      HANTRO_LOG(HANTRO_LEVEL_WARNING, "inst %lx exit itself before destroy. \n", h->instance_id);
+      HANTRO_LOG(HANTRO_LEVEL_WARNING, "inst %"PRIx64" exit itself before destroy. \n", h->instance_id);
     free(h->codec);
     h->codec = NULL;
   }
